==> zio-aws-rds_2.12-5.17.129.1-sources.jar: zio/aws/rds/model/package.scala <==
package zio.aws.rds
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.rds.model.primitives.BucketName.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AwsBackupRecoveryPointArn extends Subtype[String]
    type AwsBackupRecoveryPointArn =
      zio.aws.rds.model.primitives.AwsBackupRecoveryPointArn.Type
    object BooleanOptional extends Subtype[Boolean]
    type BooleanOptional = zio.aws.rds.model.primitives.BooleanOptional.Type
    object BucketName extends Subtype[String]
    type BucketName = zio.aws.rds.model.primitives.BucketName.Type
    object CustomDBEngineVersionManifest extends Subtype[String]
    type CustomDBEngineVersionManifest =
      zio.aws.rds.model.primitives.CustomDBEngineVersionManifest.Type
    object CustomEngineName extends Subtype[String]
    type CustomEngineName = zio.aws.rds.model.primitives.CustomEngineName.Type
    object CustomEngineVersion extends Subtype[String]
    type CustomEngineVersion =
      zio.aws.rds.model.primitives.CustomEngineVersion.Type
    object DBClusterIdentifier extends Subtype[String]
    type DBClusterIdentifier =
      zio.aws.rds.model.primitives.DBClusterIdentifier.Type
    object DBProxyEndpointName extends Subtype[String]
    type DBProxyEndpointName =
      zio.aws.rds.model.primitives.DBProxyEndpointName.Type
    object DBProxyName extends Subtype[String]
    type DBProxyName = zio.aws.rds.model.primitives.DBProxyName.Type
    object Description extends Subtype[String]
    type Description = zio.aws.rds.model.primitives.Description.Type
    object DoubleOptional extends Subtype[Double]
    type DoubleOptional = zio.aws.rds.model.primitives.DoubleOptional.Type
    object GlobalClusterIdentifier extends Subtype[String]
    type GlobalClusterIdentifier =
      zio.aws.rds.model.primitives.GlobalClusterIdentifier.Type
    object Integer extends Subtype[Int]
    type Integer = zio.aws.rds.model.primitives.Integer.Type
    object IntegerOptional extends Subtype[Int]
    type IntegerOptional = zio.aws.rds.model.primitives.IntegerOptional.Type
    object KmsKeyIdOrArn extends Subtype[String]
    type KmsKeyIdOrArn = zio.aws.rds.model.primitives.KmsKeyIdOrArn.Type
    object LongOptional extends Subtype[Long]
    type LongOptional = zio.aws.rds.model.primitives.LongOptional.Type
    object MaxRecords extends Subtype[Int]
    type MaxRecords = zio.aws.rds.model.primitives.MaxRecords.Type
    object String255 extends Subtype[String]
    type String255 = zio.aws.rds.model.primitives.String255.Type
    object StringSensitive extends Subtype[String]
    type StringSensitive = zio.aws.rds.model.primitives.StringSensitive.Type
    object TStamp extends Subtype[Instant]
    type TStamp = zio.aws.rds.model.primitives.TStamp.Type
  }
  type AccountQuotaList = List[zio.aws.rds.model.AccountQuota]
  type ActivityStreamModeList = List[String]
  type AttributeValueList = List[String]
  type AvailabilityZoneList = List[zio.aws.rds.model.AvailabilityZone]
  type AvailabilityZones = List[String]
  type AvailableProcessorFeatureList =
    List[zio.aws.rds.model.AvailableProcessorFeature]
  type CertificateList = List[zio.aws.rds.model.Certificate]
  type CustomAvailabilityZoneList =
    List[zio.aws.rds.model.CustomAvailabilityZone]
  type DBClusterBacktrackList = List[zio.aws.rds.model.DBClusterBacktrack]
  type DBClusterEndpointList = List[zio.aws.rds.model.DBClusterEndpoint]
  type DBClusterList = List[zio.aws.rds.model.DBCluster]
  type DBClusterMemberList = List[zio.aws.rds.model.DBClusterMember]
  type DBClusterOptionGroupMemberships =
    List[zio.aws.rds.model.DBClusterOptionGroupStatus]
  type DBClusterParameterGroupList =
    List[zio.aws.rds.model.DBClusterParameterGroup]
  type DBClusterRoles = List[zio.aws.rds.model.DBClusterRole]
  type DBClusterSnapshotAttributeList =
    List[zio.aws.rds.model.DBClusterSnapshotAttribute]
  type DBClusterSnapshotList = List[zio.aws.rds.model.DBClusterSnapshot]
  type DBEngineVersionList = List[zio.aws.rds.model.DBEngineVersion]
  type DBInstanceAutomatedBackupList =
    List[zio.aws.rds.model.DBInstanceAutomatedBackup]
  type DBInstanceAutomatedBackupsReplicationList =
    List[zio.aws.rds.model.DBInstanceAutomatedBackupsReplication]
  type DBInstanceList = List[zio.aws.rds.model.DBInstance]
  type DBInstanceRoles = List[zio.aws.rds.model.DBInstanceRole]
  type DBInstanceStatusInfoList = List[zio.aws.rds.model.DBInstanceStatusInfo]
  type DBParameterGroupList = List[zio.aws.rds.model.DBParameterGroup]
  type DBParameterGroupStatusList =
    List[zio.aws.rds.model.DBParameterGroupStatus]
  type DBProxyEndpointList = List[zio.aws.rds.model.DBProxyEndpoint]
  type DBProxyList = List[zio.aws.rds.model.DBProxy]
  type DBSecurityGroupMembershipList =
    List[zio.aws.rds.model.DBSecurityGroupMembership]
  type DBSecurityGroupNameList = List[String]
  type DBSecurityGroups = List[zio.aws.rds.model.DBSecurityGroup]
  type DBSnapshotAttributeList = List[zio.aws.rds.model.DBSnapshotAttribute]
  type DBSnapshotList = List[zio.aws.rds.model.DBSnapshot]
  type DBSubnetGroups = List[zio.aws.rds.model.DBSubnetGroup]
  type DescribeDBLogFilesList =
    List[zio.aws.rds.model.DescribeDBLogFilesDetails]
  type DomainMembershipList = List[zio.aws.rds.model.DomainMembership]
  type DoubleRangeList = List[zio.aws.rds.model.DoubleRange]
  type EC2SecurityGroupList = List[zio.aws.rds.model.EC2SecurityGroup]
  type EngineModeList = List[String]
  type EventCategoriesList = List[String]
  type EventCategoriesMapList = List[zio.aws.rds.model.EventCategoriesMap]
  type EventList = List[zio.aws.rds.model.Event]
  type EventSubscriptionsList = List[zio.aws.rds.model.EventSubscription]
  type ExportTasksList = List[zio.aws.rds.model.ExportTask]
  type FeatureNameList = List[String]
  type FilterList = List[zio.aws.rds.model.Filter]
  type FilterValueList = List[String]
  type GlobalClusterList = List[zio.aws.rds.model.GlobalCluster]
  type GlobalClusterMemberList = List[zio.aws.rds.model.GlobalClusterMember]
  type IPRangeList = List[zio.aws.rds.model.IPRange]
  type InstallationMediaList = List[zio.aws.rds.model.InstallationMedia]
  type KeyList = List[String]
  type LogTypeList = List[String]
  type MinimumEngineVersionPerAllowedValueList =
    List[zio.aws.rds.model.MinimumEngineVersionPerAllowedValue]
  type OptionConfigurationList = List[zio.aws.rds.model.OptionConfiguration]
  type OptionGroupMembershipList = List[zio.aws.rds.model.OptionGroupMembership]
  type OptionGroupOptionSettingsList =
    List[zio.aws.rds.model.OptionGroupOptionSetting]
  type OptionGroupOptionVersionsList = List[zio.aws.rds.model.OptionVersion]
  type OptionGroupOptionsList = List[zio.aws.rds.model.OptionGroupOption]
  type OptionGroupsList = List[zio.aws.rds.model.OptionGroup]
  type OptionNamesList = List[String]
  type OptionSettingConfigurationList = List[zio.aws.rds.model.OptionSetting]
  type OptionSettingsList = List[zio.aws.rds.model.OptionSetting]
  type OptionsConflictsWith = List[String]
  type OptionsDependedOn = List[String]
  type OptionsList = List[zio.aws.rds.model.Option]
  type OrderableDBInstanceOptionsList =
    List[zio.aws.rds.model.OrderableDBInstanceOption]
  type ParametersList = List[zio.aws.rds.model.Parameter]
  type PendingMaintenanceActionDetails =
    List[zio.aws.rds.model.PendingMaintenanceAction]
  type PendingMaintenanceActions =
    List[zio.aws.rds.model.ResourcePendingMaintenanceActions]
  type ProcessorFeatureList = List[zio.aws.rds.model.ProcessorFeature]
  type RangeList = List[zio.aws.rds.model.Range]
  type ReadReplicaDBClusterIdentifierList = List[String]
  type ReadReplicaDBInstanceIdentifierList = List[String]
  type ReadReplicaIdentifierList = List[String]
  type ReadersArnList = List[String]
  type RecurringChargeList = List[zio.aws.rds.model.RecurringCharge]
  type ReservedDBInstanceList = List[zio.aws.rds.model.ReservedDBInstance]
  type ReservedDBInstancesOfferingList =
    List[zio.aws.rds.model.ReservedDBInstancesOffering]
  type SourceIdsList = List[String]
  type SourceRegionList = List[zio.aws.rds.model.SourceRegion]
  type StringList = List[String]
  type SubnetIdentifierList = List[String]
  type SubnetList = List[zio.aws.rds.model.Subnet]
  type SupportedCharacterSetsList = List[zio.aws.rds.model.CharacterSet]
  type SupportedTimezonesList = List[zio.aws.rds.model.Timezone]
  type TagList = List[zio.aws.rds.model.Tag]
  type TargetGroupList = List[zio.aws.rds.model.DBProxyTargetGroup]
  type TargetList = List[zio.aws.rds.model.DBProxyTarget]
  type UserAuthConfigInfoList = List[zio.aws.rds.model.UserAuthConfigInfo]
  type UserAuthConfigList = List[zio.aws.rds.model.UserAuthConfig]
  type ValidStorageOptionsList = List[zio.aws.rds.model.ValidStorageOptions]
  type ValidUpgradeTargetList = List[zio.aws.rds.model.UpgradeTarget]
  type VpcSecurityGroupIdList = List[String]
  type VpcSecurityGroupMembershipList =
    List[zio.aws.rds.model.VpcSecurityGroupMembership]
}

==> zio-aws-rds_2.12-5.17.155.2-sources.jar: zio/aws/rds/model/package.scala <==
package zio.aws.rds
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.rds.model.primitives.BucketName.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AwsBackupRecoveryPointArn extends Subtype[String]
    type AwsBackupRecoveryPointArn =
      zio.aws.rds.model.primitives.AwsBackupRecoveryPointArn.Type
    type BooleanOptional = Boolean
    object BucketName extends Subtype[String]
    type BucketName = zio.aws.rds.model.primitives.BucketName.Type
    object CustomDBEngineVersionManifest extends Subtype[String]
    type CustomDBEngineVersionManifest =
      zio.aws.rds.model.primitives.CustomDBEngineVersionManifest.Type
    object CustomEngineName extends Subtype[String]
    type CustomEngineName = zio.aws.rds.model.primitives.CustomEngineName.Type
    object CustomEngineVersion extends Subtype[String]
    type CustomEngineVersion =
      zio.aws.rds.model.primitives.CustomEngineVersion.Type
    object DBClusterIdentifier extends Subtype[String]
    type DBClusterIdentifier =
      zio.aws.rds.model.primitives.DBClusterIdentifier.Type
    object DBProxyEndpointName extends Subtype[String]
    type DBProxyEndpointName =
      zio.aws.rds.model.primitives.DBProxyEndpointName.Type
    object DBProxyName extends Subtype[String]
    type DBProxyName = zio.aws.rds.model.primitives.DBProxyName.Type
    object Description extends Subtype[String]
    type Description = zio.aws.rds.model.primitives.Description.Type
    type DoubleOptional = Double
    object GlobalClusterIdentifier extends Subtype[String]
    type GlobalClusterIdentifier =
      zio.aws.rds.model.primitives.GlobalClusterIdentifier.Type
    type Integer = Int
    type IntegerOptional = Int
    object KmsKeyIdOrArn extends Subtype[String]
    type KmsKeyIdOrArn = zio.aws.rds.model.primitives.KmsKeyIdOrArn.Type
    type LongOptional = Long
    object MaxRecords extends Subtype[Int]
    type MaxRecords = zio.aws.rds.model.primitives.MaxRecords.Type
    object String255 extends Subtype[String]
    type String255 = zio.aws.rds.model.primitives.String255.Type
    object StringSensitive extends Subtype[String]
    type StringSensitive = zio.aws.rds.model.primitives.StringSensitive.Type
    object TStamp extends Subtype[Instant]
    type TStamp = zio.aws.rds.model.primitives.TStamp.Type
  }
  type AccountQuotaList = List[zio.aws.rds.model.AccountQuota]
  type ActivityStreamModeList = List[String]
  type AttributeValueList = List[String]
  type AvailabilityZoneList = List[zio.aws.rds.model.AvailabilityZone]
  type AvailabilityZones = List[String]
  type AvailableProcessorFeatureList =
    List[zio.aws.rds.model.AvailableProcessorFeature]
  type CertificateList = List[zio.aws.rds.model.Certificate]
  type CustomAvailabilityZoneList =
    List[zio.aws.rds.model.CustomAvailabilityZone]
  type DBClusterBacktrackList = List[zio.aws.rds.model.DBClusterBacktrack]
  type DBClusterEndpointList = List[zio.aws.rds.model.DBClusterEndpoint]
  type DBClusterList = List[zio.aws.rds.model.DBCluster]
  type DBClusterMemberList = List[zio.aws.rds.model.DBClusterMember]
  type DBClusterOptionGroupMemberships =
    List[zio.aws.rds.model.DBClusterOptionGroupStatus]
  type DBClusterParameterGroupList =
    List[zio.aws.rds.model.DBClusterParameterGroup]
  type DBClusterRoles = List[zio.aws.rds.model.DBClusterRole]
  type DBClusterSnapshotAttributeList =
    List[zio.aws.rds.model.DBClusterSnapshotAttribute]
  type DBClusterSnapshotList = List[zio.aws.rds.model.DBClusterSnapshot]
  type DBEngineVersionList = List[zio.aws.rds.model.DBEngineVersion]
  type DBInstanceAutomatedBackupList =
    List[zio.aws.rds.model.DBInstanceAutomatedBackup]
  type DBInstanceAutomatedBackupsReplicationList =
    List[zio.aws.rds.model.DBInstanceAutomatedBackupsReplication]
  type DBInstanceList = List[zio.aws.rds.model.DBInstance]
  type DBInstanceRoles = List[zio.aws.rds.model.DBInstanceRole]
  type DBInstanceStatusInfoList = List[zio.aws.rds.model.DBInstanceStatusInfo]
  type DBParameterGroupList = List[zio.aws.rds.model.DBParameterGroup]
  type DBParameterGroupStatusList =
    List[zio.aws.rds.model.DBParameterGroupStatus]
  type DBProxyEndpointList = List[zio.aws.rds.model.DBProxyEndpoint]
  type DBProxyList = List[zio.aws.rds.model.DBProxy]
  type DBSecurityGroupMembershipList =
    List[zio.aws.rds.model.DBSecurityGroupMembership]
  type DBSecurityGroupNameList = List[String]
  type DBSecurityGroups = List[zio.aws.rds.model.DBSecurityGroup]
  type DBSnapshotAttributeList = List[zio.aws.rds.model.DBSnapshotAttribute]
  type DBSnapshotList = List[zio.aws.rds.model.DBSnapshot]
  type DBSubnetGroups = List[zio.aws.rds.model.DBSubnetGroup]
  type DescribeDBLogFilesList =
    List[zio.aws.rds.model.DescribeDBLogFilesDetails]
  type DomainMembershipList = List[zio.aws.rds.model.DomainMembership]
  type DoubleRangeList = List[zio.aws.rds.model.DoubleRange]
  type EC2SecurityGroupList = List[zio.aws.rds.model.EC2SecurityGroup]
  type EngineModeList = List[String]
  type EventCategoriesList = List[String]
  type EventCategoriesMapList = List[zio.aws.rds.model.EventCategoriesMap]
  type EventList = List[zio.aws.rds.model.Event]
  type EventSubscriptionsList = List[zio.aws.rds.model.EventSubscription]
  type ExportTasksList = List[zio.aws.rds.model.ExportTask]
  type FeatureNameList = List[String]
  type FilterList = List[zio.aws.rds.model.Filter]
  type FilterValueList = List[String]
  type GlobalClusterList = List[zio.aws.rds.model.GlobalCluster]
  type GlobalClusterMemberList = List[zio.aws.rds.model.GlobalClusterMember]
  type IPRangeList = List[zio.aws.rds.model.IPRange]
  type InstallationMediaList = List[zio.aws.rds.model.InstallationMedia]
  type KeyList = List[String]
  type LogTypeList = List[String]
  type MinimumEngineVersionPerAllowedValueList =
    List[zio.aws.rds.model.MinimumEngineVersionPerAllowedValue]
  type OptionConfigurationList = List[zio.aws.rds.model.OptionConfiguration]
  type OptionGroupMembershipList = List[zio.aws.rds.model.OptionGroupMembership]
  type OptionGroupOptionSettingsList =
    List[zio.aws.rds.model.OptionGroupOptionSetting]
  type OptionGroupOptionVersionsList = List[zio.aws.rds.model.OptionVersion]
  type OptionGroupOptionsList = List[zio.aws.rds.model.OptionGroupOption]
  type OptionGroupsList = List[zio.aws.rds.model.OptionGroup]
  type OptionNamesList = List[String]
  type OptionSettingConfigurationList = List[zio.aws.rds.model.OptionSetting]
  type OptionSettingsList = List[zio.aws.rds.model.OptionSetting]
  type OptionsConflictsWith = List[String]
  type OptionsDependedOn = List[String]
  type OptionsList = List[zio.aws.rds.model.Option]
  type OrderableDBInstanceOptionsList =
    List[zio.aws.rds.model.OrderableDBInstanceOption]
  type ParametersList = List[zio.aws.rds.model.Parameter]
  type PendingMaintenanceActionDetails =
    List[zio.aws.rds.model.PendingMaintenanceAction]
  type PendingMaintenanceActions =
    List[zio.aws.rds.model.ResourcePendingMaintenanceActions]
  type ProcessorFeatureList = List[zio.aws.rds.model.ProcessorFeature]
  type RangeList = List[zio.aws.rds.model.Range]
  type ReadReplicaDBClusterIdentifierList = List[String]
  type ReadReplicaDBInstanceIdentifierList = List[String]
  type ReadReplicaIdentifierList = List[String]
  type ReadersArnList = List[String]
  type RecurringChargeList = List[zio.aws.rds.model.RecurringCharge]
  type ReservedDBInstanceList = List[zio.aws.rds.model.ReservedDBInstance]
  type ReservedDBInstancesOfferingList =
    List[zio.aws.rds.model.ReservedDBInstancesOffering]
  type SourceIdsList = List[String]
  type SourceRegionList = List[zio.aws.rds.model.SourceRegion]
  type StringList = List[String]
  type SubnetIdentifierList = List[String]
  type SubnetList = List[zio.aws.rds.model.Subnet]
  type SupportedCharacterSetsList = List[zio.aws.rds.model.CharacterSet]
  type SupportedTimezonesList = List[zio.aws.rds.model.Timezone]
  type TagList = List[zio.aws.rds.model.Tag]
  type TargetGroupList = List[zio.aws.rds.model.DBProxyTargetGroup]
  type TargetList = List[zio.aws.rds.model.DBProxyTarget]
  type UserAuthConfigInfoList = List[zio.aws.rds.model.UserAuthConfigInfo]
  type UserAuthConfigList = List[zio.aws.rds.model.UserAuthConfig]
  type ValidStorageOptionsList = List[zio.aws.rds.model.ValidStorageOptions]
  type ValidUpgradeTargetList = List[zio.aws.rds.model.UpgradeTarget]
  type VpcSecurityGroupIdList = List[String]
  type VpcSecurityGroupMembershipList =
    List[zio.aws.rds.model.VpcSecurityGroupMembership]
}
